# User guide

Here, you will soon find user guides with instructions on how to use BayBE.
These are currently being worked on.
In the meantime, we refer to the [examples](../../examples/examples) instead.

For full transparency, we note that sthe user guides were partially written with the help of Large Language Models.

```{toctree}
Campaigns <campaigns>
Constraints <constraints>
Objective <objective>
Parameters <parameters>
Recommender <recommender>
Search Spaces <searchspace>
Simulation <simulation>
Strategy <strategy>
Surrogates <surrogates>
Targets <targets>
Transfer Learning <transfer_learning>
```